@@ -355,19 +355,27 @@ test_that("strata with includeNA()", {
 
 
 test_that("01/31/2019: modpval.tableby (#174, #175)", {
-  tmp <- tableby(sex ~ age, data = mockstudy, strata = fu.stat, test = FALSE)
+  tmp <- tableby(sex ~ age + arm, data = mockstudy, strata = fu.stat, test = FALSE)
   expect_true(!any(c("test", "p.value") %in% names(as.data.frame(tmp))))
-  tmp <- modpval.tableby(tmp, data.frame(y = "sex", strata = "1", x = "age", p = 1), use.pname = TRUE)
+  tmp <- modpval.tableby(tmp, data.frame(y = "sex", strata = c("1", "2"), x = c("age", "arm"), p = c(1, 0.5)), use.pname = TRUE)
   expect_identical(
     capture.kable(summary(tmp, pfootnote = TRUE, text = TRUE)),
-    c("|fu.stat |             |  Male (N=916)   | Female (N=583)  | Total (N=1499)  |    p     |",
-      "|:-------|:------------|:---------------:|:---------------:|:---------------:|:--------:|",
-      "|1       |Age in Years |                 |                 |                 | 1.000^1^ |",
-      "|        |-  Mean (SD) | 58.253 (12.048) | 61.018 (10.649) | 59.336 (11.561) |          |",
-      "|        |-  Range     | 32.000 - 85.000 | 35.000 - 80.000 | 32.000 - 85.000 |          |",
-      "|2       |Age in Years |                 |                 |                 |          |",
-      "|        |-  Mean (SD) | 60.686 (11.278) | 59.059 (11.824) | 60.054 (11.516) |          |",
-      "|        |-  Range     | 19.000 - 88.000 | 22.000 - 88.000 | 19.000 - 88.000 |          |",
+    c("|fu.stat |              |  Male (N=916)   | Female (N=583)  | Total (N=1499)  |    p     |",
+      "|:-------|:-------------|:---------------:|:---------------:|:---------------:|:--------:|",
+      "|1       |Age in Years  |                 |                 |                 | 1.000^1^ |",
+      "|        |-  Mean (SD)  | 58.253 (12.048) | 61.018 (10.649) | 59.336 (11.561) |          |",
+      "|        |-  Range      | 32.000 - 85.000 | 35.000 - 80.000 | 32.000 - 85.000 |          |",
+      "|        |Treatment Arm |                 |                 |                 |          |",
+      "|        |-  A: IFL     |   14 (16.1%)    |    4 (7.1%)     |   18 (12.6%)    |          |",
+      "|        |-  F: FOLFOX  |   56 (64.4%)    |   43 (76.8%)    |   99 (69.2%)    |          |",
+      "|        |-  G: IROX    |   17 (19.5%)    |    9 (16.1%)    |   26 (18.2%)    |          |",
+      "|2       |Age in Years  |                 |                 |                 |          |",
+      "|        |-  Mean (SD)  | 60.686 (11.278) | 59.059 (11.824) | 60.054 (11.516) |          |",
+      "|        |-  Range      | 19.000 - 88.000 | 22.000 - 88.000 | 19.000 - 88.000 |          |",
+      "|        |Treatment Arm |                 |                 |                 | 0.500^1^ |",
+      "|        |-  A: IFL     |   263 (31.7%)   |   147 (27.9%)   |   410 (30.2%)   |          |",
+      "|        |-  F: FOLFOX  |   355 (42.8%)   |   237 (45.0%)   |   592 (43.7%)   |          |",
+      "|        |-  G: IROX    |   211 (25.5%)   |   143 (27.1%)   |   354 (26.1%)   |          |",
       "1. Modified by user"
     )
   )
