@@ -228,3 +228,55 @@ test_that("07/17/2019: fix bug with confidence limits and count (#234, #235)", {
     )
   )
 })
+
+test_that("12/27/2019: Npct works (#263)", {
+  d <- data.frame(
+    tp = rep(c("Time 1", "Time 2"), times = 4),
+    id = c(1, 1, 2, 2, 3, 3, 4, 4),
+    a = c(1, 1, 2, 2, 3, 3, 4, 4),
+    b = c(1, 0, 2, 0, 3, 0, 4, 0)
+  )
+  expect_identical(
+    capture.kable(summary(paired(tp ~ notest(a) + b, id = id, data = d, numeric.stats = c("meansd", "Npct")), text = TRUE)),
+    c("|             | Time 1 (N=4)  | Time 2 (N=4)  | Difference (N=4) | p value|",
+      "|:------------|:-------------:|:-------------:|:----------------:|-------:|",
+      "|a            |               |               |                  |        |",
+      "|-  Mean (SD) | 2.500 (1.291) | 2.500 (1.291) |  0.000 (0.000)   |        |",
+      "|-  N (Pct)   |   4 (50.0%)   |   4 (50.0%)   |     0 (0.0%)     |        |",
+      "|b            |               |               |                  |   0.030|",
+      "|-  Mean (SD) | 2.500 (1.291) | 0.000 (0.000) |  -2.500 (1.291)  |        |",
+      "|-  N (Pct)   |   4 (50.0%)   |   4 (50.0%)   |    4 (100.0%)    |        |"
+    )
+  )
+})
+
+test_that("12/27/2019: changing the difference label (#271)", {
+  expect_identical(
+    capture.kable(summary(paired(tp ~ Cat + Fac + Num, data = dat2, id = id, signed.rank.exact = FALSE, cat.stats = c("countpct", "countrowpct"),
+                                 stats.labels = list(meansd = "Mean (sd)", range = "Ran", difference = "Diff")), text = TRUE)),
+    c("|             |    1 (N=4)    |    2 (N=4)    |   Diff (N=4)   | p value|",
+      "|:------------|:-------------:|:-------------:|:--------------:|-------:|",
+      "|Cat          |               |               |                |   1.000|",
+      "|-  A         |   2 (50.0%)   |   2 (50.0%)   |   1 (50.0%)    |        |",
+      "|-  B         |   2 (50.0%)   |   2 (50.0%)   |   1 (50.0%)    |        |",
+      "|-  A         |   2 (50.0%)   |   2 (50.0%)   |   1 (50.0%)    |        |",
+      "|-  B         |   2 (50.0%)   |   2 (50.0%)   |   1 (50.0%)    |        |",
+      "|Fac          |               |               |                |   0.261|",
+      "|-  A         |   2 (50.0%)   |   1 (25.0%)   |   2 (100.0%)   |        |",
+      "|-  B         |   1 (25.0%)   |   2 (50.0%)   |   1 (100.0%)   |        |",
+      "|-  C         |   1 (25.0%)   |   1 (25.0%)   |   1 (100.0%)   |        |",
+      "|-  A         |   2 (66.7%)   |   1 (33.3%)   |   2 (100.0%)   |        |",
+      "|-  B         |   1 (33.3%)   |   2 (66.7%)   |   1 (100.0%)   |        |",
+      "|-  C         |   1 (50.0%)   |   1 (50.0%)   |   1 (100.0%)   |        |",
+      "|Num          |               |               |                |   0.391|",
+      "|-  Mean (sd) | 2.750 (1.258) | 3.250 (0.957) | 0.500 (1.000)  |        |",
+      "|-  Ran       | 1.000 - 4.000 | 2.000 - 4.000 | -1.000 - 1.000 |        |"
+    )
+  )
+})
+
+test_that("12/27/2019: informative error when no stats are computed (#273)", {
+  expect_error(summary(paired(tp ~ Cat, data = dat2, id = id, cat.stats = "Nmiss")), "Nothing to show for variable")
+})
+
+
